@@ -1,3 +1,4 @@
+from time import sleep
 import requests
 from requests.exceptions import ConnectionError
 
@@ -48,6 +49,8 @@ class SanityTest:
       try:
         response = requests.get(request_address, timeout=self.sanity_test_timeout_sec)
       except ConnectionError:
+        self.logger.info("Sleeping for 1 sec..")
+        sleep(1)#so that we don't connect too often
         continue
       if response.status_code in [200, 201]:
         break
